@@ -1,53 +1,53 @@
 data = (
-'[?]',    # 0x00
-'[?]',    # 0x01
-'[?]',    # 0x02
-'[?]',    # 0x03
-'[?]',    # 0x04
-'[?]',    # 0x05
-'[?]',    # 0x06
-'[?]',    # 0x07
-'[?]',    # 0x08
-'[?]',    # 0x09
-'[?]',    # 0x0a
-'[?]',    # 0x0b
-'[?]',    # 0x0c
-'[?]',    # 0x0d
-'[?]',    # 0x0e
-'[?]',    # 0x0f
-'[?]',    # 0x10
-'[?]',    # 0x11
-'[?]',    # 0x12
-'[?]',    # 0x13
-'[?]',    # 0x14
-'[?]',    # 0x15
-'[?]',    # 0x16
-'[?]',    # 0x17
-'[?]',    # 0x18
-'[?]',    # 0x19
-'[?]',    # 0x1a
-'[?]',    # 0x1b
-'[?]',    # 0x1c
-'[?]',    # 0x1d
-'[?]',    # 0x1e
-'[?]',    # 0x1f
-'[?]',    # 0x20
-'[?]',    # 0x21
-'[?]',    # 0x22
-'[?]',    # 0x23
-'[?]',    # 0x24
-'[?]',    # 0x25
-'[?]',    # 0x26
-'[?]',    # 0x27
-'[?]',    # 0x28
-'[?]',    # 0x29
-'[?]',    # 0x2a
-'[?]',    # 0x2b
-'[?]',    # 0x2c
-'[?]',    # 0x2d
-'[?]',    # 0x2e
-'[?]',    # 0x2f
-'[?]',    # 0x30
+None,    # 0x00
+None,    # 0x01
+None,    # 0x02
+None,    # 0x03
+None,    # 0x04
+None,    # 0x05
+None,    # 0x06
+None,    # 0x07
+None,    # 0x08
+None,    # 0x09
+None,    # 0x0a
+None,    # 0x0b
+None,    # 0x0c
+None,    # 0x0d
+None,    # 0x0e
+None,    # 0x0f
+None,    # 0x10
+None,    # 0x11
+None,    # 0x12
+None,    # 0x13
+None,    # 0x14
+None,    # 0x15
+None,    # 0x16
+None,    # 0x17
+None,    # 0x18
+None,    # 0x19
+None,    # 0x1a
+None,    # 0x1b
+None,    # 0x1c
+None,    # 0x1d
+None,    # 0x1e
+None,    # 0x1f
+None,    # 0x20
+None,    # 0x21
+None,    # 0x22
+None,    # 0x23
+None,    # 0x24
+None,    # 0x25
+None,    # 0x26
+None,    # 0x27
+None,    # 0x28
+None,    # 0x29
+None,    # 0x2a
+None,    # 0x2b
+None,    # 0x2c
+None,    # 0x2d
+None,    # 0x2e
+None,    # 0x2f
+None,    # 0x30
 'A',    # 0x31
 'B',    # 0x32
 'G',    # 0x33
@@ -86,8 +86,8 @@ data = (
 'K`',    # 0x54
 'O',    # 0x55
 'F',    # 0x56
-'[?]',    # 0x57
-'[?]',    # 0x58
+None,    # 0x57
+None,    # 0x58
 '<',    # 0x59
 '\'',    # 0x5a
 '/',    # 0x5b
@@ -95,7 +95,7 @@ data = (
 ',',    # 0x5d
 '?',    # 0x5e
 '.',    # 0x5f
-'[?]',    # 0x60
+None,    # 0x60
 'a',    # 0x61
 'b',    # 0x62
 'g',    # 0x63
@@ -135,15 +135,15 @@ data = (
 'o',    # 0x85
 'f',    # 0x86
 'ew',    # 0x87
-'[?]',    # 0x88
+None,    # 0x88
 ':',    # 0x89
 '-',    # 0x8a
-'[?]',    # 0x8b
-'[?]',    # 0x8c
-'[?]',    # 0x8d
-'[?]',    # 0x8e
-'[?]',    # 0x8f
-'[?]',    # 0x90
+None,    # 0x8b
+None,    # 0x8c
+None,    # 0x8d
+None,    # 0x8e
+None,    # 0x8f
+None,    # 0x90
 '',    # 0x91
 '',    # 0x92
 '',    # 0x93
@@ -161,7 +161,7 @@ data = (
 '',    # 0x9f
 '',    # 0xa0
 '',    # 0xa1
-'[?]',    # 0xa2
+'',    # 0xa2
 '',    # 0xa3
 '',    # 0xa4
 '',    # 0xa5
@@ -185,36 +185,36 @@ data = (
 'a',    # 0xb7
 'a',    # 0xb8
 'o',    # 0xb9
-'[?]',    # 0xba
+'o',    # 0xba
 'u',    # 0xbb
 '\'',    # 0xbc
 '',    # 0xbd
 '-',    # 0xbe
-'',    # 0xbf
+'-',    # 0xbf
 '|',    # 0xc0
 '',    # 0xc1
 '',    # 0xc2
 ':',    # 0xc3
 '',    # 0xc4
-'[?]',    # 0xc5
-'[?]',    # 0xc6
-'[?]',    # 0xc7
-'[?]',    # 0xc8
-'[?]',    # 0xc9
-'[?]',    # 0xca
-'[?]',    # 0xcb
-'[?]',    # 0xcc
-'[?]',    # 0xcd
-'[?]',    # 0xce
-'[?]',    # 0xcf
-'',    # 0xd0
+'',    # 0xc5
+'n',    # 0xc6
+'o',    # 0xc7
+None,    # 0xc8
+None,    # 0xc9
+None,    # 0xca
+None,    # 0xcb
+None,    # 0xcc
+None,    # 0xcd
+None,    # 0xce
+None,    # 0xcf
+'A',    # 0xd0
 'b',    # 0xd1
 'g',    # 0xd2
 'd',    # 0xd3
 'h',    # 0xd4
 'v',    # 0xd5
 'z',    # 0xd6
-'kh',    # 0xd7
+'KH',    # 0xd7
 't',    # 0xd8
 'y',    # 0xd9
 'k',    # 0xda
@@ -228,30 +228,30 @@ data = (
 '`',    # 0xe2
 'p',    # 0xe3
 'p',    # 0xe4
-'ts',    # 0xe5
-'ts',    # 0xe6
+'TS',    # 0xe5
+'TS',    # 0xe6
 'q',    # 0xe7
 'r',    # 0xe8
-'sh',    # 0xe9
+'SH',    # 0xe9
 't',    # 0xea
-'[?]',    # 0xeb
-'[?]',    # 0xec
-'[?]',    # 0xed
-'[?]',    # 0xee
-'[?]',    # 0xef
+None,    # 0xeb
+None,    # 0xec
+None,    # 0xed
+None,    # 0xee
+None,    # 0xef
 'V',    # 0xf0
-'oy',    # 0xf1
+'OY',    # 0xf1
 'i',    # 0xf2
 '\'',    # 0xf3
 '"',    # 0xf4
-'[?]',    # 0xf5
-'[?]',    # 0xf6
-'[?]',    # 0xf7
-'[?]',    # 0xf8
-'[?]',    # 0xf9
-'[?]',    # 0xfa
-'[?]',    # 0xfb
-'[?]',    # 0xfc
-'[?]',    # 0xfd
-'[?]',    # 0xfe
+'v',    # 0xf5
+'n',    # 0xf6
+'q',    # 0xf7
+None,    # 0xf8
+None,    # 0xf9
+None,    # 0xfa
+None,    # 0xfb
+None,    # 0xfc
+None,    # 0xfd
+None,    # 0xfe
 )
